@@ -331,6 +331,7 @@ static double *TT2000NULL = 0;
 #define BLOCKINGFACTOR_TOO_SMALL2       ((CDFstatus) 1012)
 #define STRING_NOT_UTF8_ENCODING        ((CDFstatus) 1013)
 #define BLOCKINGFACTOR_TOO_LARGE        ((CDFstatus) 1014)
+#define CACHESIZE_TOO_SMALL             ((CDFstatus) 1015)
 
 #define CDF_OK                          ((CDFstatus) 0)
 
@@ -1869,7 +1870,7 @@ CDFlib (SELECT_, CDF_, id, \
 #if defined(PROTOs_)
 #  define PROTOARGs(args) args
 #else
-#  define PROTOARGs(args) ()
+#  define PROTOARGs(args) (void)
 #endif
 
 #if defined(BUILDINGforIDL)
@@ -2017,6 +2018,9 @@ VISIBLE_PREFIX CDFstatus CDFgetzVarSpec PROTOARGs((
 VISIBLE_PREFIX CDFstatus CDFreadzVarPadValue PROTOARGs((
   CDFid id, long varNum, long *dataType, long *numElms, CDFdata *buffer
 ));
+VISIBLE_PREFIX CDFstatus CDFreadzVarValue PROTOARGs((
+  CDFid id, long varNum, long recNum, long *indices, CDFdata *buffer
+));
 VISIBLE_PREFIX CDFstatus CDFreadzVarAllByVarID PROTOARGs((
   CDFid id, long varNum, long *numRecs, long *dataType, long *numElems,
   long *numDims, long *dimSizes, long *recVary, long *dimsVary, 
@@ -2075,19 +2079,22 @@ VISIBLE_PREFIX CDFstatus CDFdeleteRecordsForAll PROTOARGs((
 VISIBLE_PREFIX void CDFsetFileBackward PROTOARGs((
   int flag
 ));
+VISIBLE_PREFIX void CDFsetFileBackward2 PROTOARGs((
+  int flag
+));
 VISIBLE_PREFIX void CDFsetFileBackwardFlag PROTOARGs((
   int flag
 ));
-VISIBLE_PREFIX int CDFgetFileBackward PROTOARGs(());
-VISIBLE_PREFIX int CDFgetFileBackwardFlag PROTOARGs(());
+VISIBLE_PREFIX int CDFgetFileBackward PROTOARGs((void));
+VISIBLE_PREFIX int CDFgetFileBackwardFlag PROTOARGs((void));
 VISIBLE_PREFIX void CDFsetChecksumMode PROTOARGs((
   long flag
 ));
-VISIBLE_PREFIX long CDFgetChecksumMode PROTOARGs(());
-VISIBLE_PREFIX int CDFgetFileBackwardEnvVar PROTOARGs(());
+VISIBLE_PREFIX long CDFgetChecksumMode PROTOARGs((void));
+VISIBLE_PREFIX int CDFgetFileBackwardEnvVar PROTOARGs((void));
 VISIBLE_PREFIX void CDFsetValidate PROTOARGs((long mode));
-VISIBLE_PREFIX int CDFgetValidate PROTOARGs(());
-VISIBLE_PREFIX int CDFgetValidateDebug PROTOARGs(());
+VISIBLE_PREFIX int CDFgetValidate PROTOARGs((void));
+VISIBLE_PREFIX int CDFgetValidateDebug PROTOARGs((void));
 VISIBLE_PREFIX void ROWtoCOL PROTOARGs((
   void *iBuffer, void *oBuffer, long numDims, long dimSizes[], long nValueBytes
 ));
@@ -2120,81 +2127,95 @@ VISIBLE_PREFIX void   toEncodeEPOCH PROTOARGs((
   double epoch, int style, char *epString
 ));
 VISIBLE_PREFIX void   encodeEPOCH PROTOARGs((
-  double epoch, char epString[EPOCH_STRING_LEN+1]
+/*  double epoch, char epString[EPOCH_STRING_LEN+1] */
+  double epoch, char *epString
 ));
 VISIBLE_PREFIX void   encodeEPOCH1 PROTOARGs((
-  double epoch, char epString[EPOCH1_STRING_LEN+1]
+/*  double epoch, char epString[EPOCH1_STRING_LEN+1] */
+  double epoch, char *epString
 ));
 VISIBLE_PREFIX void   encodeEPOCH2 PROTOARGs((
-  double epoch, char epString[EPOCH2_STRING_LEN+1]
+/*  double epoch, char epString[EPOCH2_STRING_LEN+1] */
+  double epoch, char *epString
 ));
 VISIBLE_PREFIX void   encodeEPOCH3 PROTOARGs((
-  double epoch, char epString[EPOCH3_STRING_LEN+1]
+/*  double epoch, char epString[EPOCH3_STRING_LEN+1] */
+  double epoch, char *epString
 ));
 VISIBLE_PREFIX void   encodeEPOCH4 PROTOARGs((
-  double epoch, char epString[EPOCH4_STRING_LEN+1]
+/*  double epoch, char epString[EPOCH4_STRING_LEN+1] */
+  double epoch, char *epString
 ));
 VISIBLE_PREFIX void   encodeEPOCHx PROTOARGs((
-  double epoch, char format[EPOCHx_FORMAT_MAX],
-  char encoded[EPOCHx_STRING_MAX]
+/*  double epoch, char format[EPOCHx_FORMAT_MAX], */
+/*  char encoded[EPOCHx_STRING_MAX] */
+  double epoch, char *format,
+  char *encoded
 ));
 VISIBLE_PREFIX void EPOCHtoUnixTime PROTOARGs((
-  double *epoch,
+  double epoch[],
   double *unitTime,
   int    numTimes
 ));
 VISIBLE_PREFIX void UnixTimetoEPOCH PROTOARGs((
   double *unitTime,
-  double *epoch,
+  double epoch[],
   int    numTimes
 ));
 VISIBLE_PREFIX void   EPOCH16breakdown PROTOARGs((
-  double *epoch, long *year, long *month, long *day, long *hour,
+  double epoch[], long *year, long *month, long *day, long *hour,
   long *minute, long *second, long *msec, long *usec, long *nsec, long *psec
 ));
 VISIBLE_PREFIX double computeEPOCH16 PROTOARGs((
   long year, long month, long day, long hour, long minute, long second,
-  long msec, long usec, long nsec, long psec, double *epoch
+  long msec, long usec, long nsec, long psec, double epoch[]
 ));
 VISIBLE_PREFIX double toParseEPOCH16 PROTOARGs((char *inString,
-  double *epoch
+  double epoch[]
 ));
 VISIBLE_PREFIX double parseEPOCH16 PROTOARGs((char *inString,
-  double *epoch
+  double epoch[]
 ));
 VISIBLE_PREFIX double parseEPOCH16_1 PROTOARGs((char *inStringch,
-  double *epoch
+  double epoch[]
 ));
 VISIBLE_PREFIX double parseEPOCH16_2 PROTOARGs((char *inStringch,
-  double *epoch
+  double epoch[]
 ));
 VISIBLE_PREFIX double parseEPOCH16_3 PROTOARGs((char *inStringch,
-  double *epoch
+  double epoch[]
 ));
 VISIBLE_PREFIX double parseEPOCH16_4 PROTOARGs((char *inStringch,
-  double *epoch
+  double epoch[]
 ));
 VISIBLE_PREFIX void   toEncodeEPOCH16 PROTOARGs((
-  double *epoch, int style, char *epString
+  double epoch[], int style, char *epString
 ));
 VISIBLE_PREFIX void   encodeEPOCH16 PROTOARGs((
-  double *epoch, char epString[EPOCH16_STRING_LEN+1]
+/*  double *epoch, char epString[EPOCH16_STRING_LEN+1] */
+  double epoch[], char *epString
 ));
 VISIBLE_PREFIX void   encodeEPOCH16_1 PROTOARGs((
-  double *epoch, char epString[EPOCH16_1_STRING_LEN+1]
+/*  double *epoch, char epString[EPOCH16_1_STRING_LEN+1] */
+  double epoch[], char *epString
 ));
 VISIBLE_PREFIX void   encodeEPOCH16_2 PROTOARGs((
-  double *epoch, char epString[EPOCH16_2_STRING_LEN+1]
+/*  double *epoch, char epString[EPOCH16_2_STRING_LEN+1] */
+  double epoch[], char *epString
 ));
 VISIBLE_PREFIX void   encodeEPOCH16_3 PROTOARGs((
-  double *epoch, char epString[EPOCH16_3_STRING_LEN+1]
+/*  double *epoch, char epString[EPOCH16_3_STRING_LEN+1] */
+  double epoch[], char *epString
 ));
 VISIBLE_PREFIX void   encodeEPOCH16_4 PROTOARGs((
-  double *epoch, char epString[EPOCH16_4_STRING_LEN+1]
+/*  double *epoch, char epString[EPOCH16_4_STRING_LEN+1] */
+  double epoch[], char *epString
 ));
 VISIBLE_PREFIX void   encodeEPOCH16_x PROTOARGs((
-  double *epoch, char format[EPOCHx_FORMAT_MAX],
-  char encoded[EPOCHx_STRING_MAX]
+/*  double *epoch, char format[EPOCHx_FORMAT_MAX], */
+/*  char encoded[EPOCHx_STRING_MAX] */
+  double epoch[], char *format,
+  char *encoded
 ));
 VISIBLE_PREFIX void EPOCH16toUnixTime PROTOARGs((
   double *epoch,
@@ -2278,11 +2299,11 @@ VISIBLE_PREFIX void UnixTimetoTT2000 PROTOARGs((
   long long *epoch,
   int    numTimes
 ));
-VISIBLE_PREFIX void CDFClearLeapSecondsTable PROTOARGs(());
+VISIBLE_PREFIX void CDFClearLeapSecondsTable PROTOARGs((void));
 VISIBLE_PREFIX void CDFfillLeapSecondsTable PROTOARGs((
   double **table
 ));
-VISIBLE_PREFIX int CDFgetRowsinLeapSecondsTable PROTOARGs(());
+VISIBLE_PREFIX int CDFgetRowsinLeapSecondsTable PROTOARGs((void));
 #if defined(vms)
 VISIBLE_PREFIX void CDFgetLastDateinLeapSecondsTBL PROTOARGs((
   long *year, long *month, long *day
@@ -2292,8 +2313,8 @@ VISIBLE_PREFIX void CDFgetLastDateinLeapSecondsTable PROTOARGs((
   long *year, long *month, long *day
 ));
 #endif
-VISIBLE_PREFIX char *CDFgetLeapSecondsTableEnvVar PROTOARGs(());
-VISIBLE_PREFIX int CDFgetLeapSecondsTableStatus PROTOARGs(());
+VISIBLE_PREFIX char *CDFgetLeapSecondsTableEnvVar PROTOARGs((void));
+VISIBLE_PREFIX int CDFgetLeapSecondsTableStatus PROTOARGs((void));
 #endif
 VISIBLE_PREFIX void CDF_Free_String PROTOARGs((
   long numStrings, char **strings
